#! /usr/bin/env bash

set -e

# taken from https://stackoverflow.com/a/246128
SCRIPT_DIR=$( cd -- "$( dirname -- "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )

source "${SCRIPT_DIR}"/vars.sh

TANGO_BUILD_TARGET=${TANGO_BUILD_TARGET:-all}

cmake --build ${BUILD_DIR} --target ${TANGO_BUILD_TARGET}
